%Analyzes the performance of the multiple model structure. 
%
%handles = analyze_this(mm, mm_error_log, filename_prefix)
%
%Inputs: 
%
%mm: The multiple model.
%
%mm_error_log: The error log of the multiple model.
%
%filename_prefix: The prefix for the saved PDF files. If it is the empty matrix [],
%the figures will not be saved as PDF files.
%
%Outputs:
%
%handles: A vector holding all the figure handles.

function [ handles, transitions ] = analyze_this(mm, mm_error_log, filename_prefix)

%Write out the parameters used for the experiment:
disp('Parameters: name of matlab file, name of breve file, degrees of freedom, length of desired state, #models, #epochs, feedback gain, output gain, sigma, error proportion, size of inv/forw neural network, size of rp network, learning rate')
disp(sprintf('\\parameters{%s}{%s}{%i}{%i}{%i}{%i}{%d}{%d}{%3.2f}{%d}{%s}{%s}{%3.2f}', ...
    mm(1).matlab_file,...
    mm(1).breve_file,...
    mm(1).inverse.size(end),... %since the output size of the inverse model will be equivalent to the degrees of freedom in breve
    length(mm(1).desired_state),...
    length(mm),...
    length(mm_error_log),...
    mm(1).K,...
    mm(1).output_gain,...
    mm(1).sigma,...
    mm(1).error_proportion,...
    sprintf('%i-%i-%i', mm(1).inverse.size(1), mm(1).inverse.size(2), mm(1).inverse.size(3)),...
    sprintf('%i-%i-%i', mm(1).rp.size(1), mm(1).rp.size(2), mm(1).rp.size(3)),...
    mm(1).inverse.lr))

%Plot the entire run
[handles, transitions, perf] = plot_run(mm_error_log, mm(1).desired_state);

disp([ 'The top 10 epochs: ' num2str(perf(1:10), ' %i')])

%Position the run plot properly.
set(handles(1), 'Position', [ 1 1 680 1050 ], 'PaperPositionMode', 'auto');

%Plot the epoch-specific figures, plot the last epoch. Note how the
%filename_prefix is NOT carried on - this is because we want to save the
%files here, and we want to have the chance of correcting the figures
%before saving.
handles = [handles analyze_this_epoch(mm, mm_error_log, length(mm_error_log), []) ];

%Save pdf-file if a filename prefix is supplied. The other pdf files have
%been saved in analyz_this_epoch
if ~isempty(filename_prefix)
    %Allow for correction of the legends before saving.
    input('Press enter to save the files - i.e. make adjustments to the legends NOW!')

    saveas(handles(1), [ filename_prefix '_entire_run.pdf' ]);
    saveas(handles(2), sprintf('%s_last_epoch.pdf', filename_prefix));
    saveas(handles(3), sprintf('%s_angle_vs_time_last_epoch.pdf', filename_prefix));
    saveas(handles(4), sprintf('%s_angle_and_lambda_last_epoch.pdf', filename_prefix));
end