%Analyzes a specific epoch, both in terms of forward models/feedback motor
%error/lambda values (the first plot), and total performance of the system
%(the second plot). If a filename is specified, the plots will be saved as
%PDF files.
%
%handles = analyze_this_epoch(mm, mm_error_log, epoch, filename_prefix)
%
%Inputs:
%
%mm: The multiple model structure.
%
%mm_error_log: The error log from the entire run.
%
%epoch: The epoch that is to be plotted. Can also be a vector of epochs.
%
%filename_prefix: The prefix of the filenames that will be created for each
%of the two plots. If it is the empty matrix [], no files will be created.
%
%Outputs:
%
%handles: The handles to the plots.


function handles = analyze_this_epoch(mm, mm_error_log, epoch, filename_prefix)

for k=1:length(epoch)

    %Plot the specific epoch
    handles = plot_epoch(mm_error_log, epoch(k), mm(1).context);

    %Plot the angle vs time for the desired state and what was executed during
    %the simulation.
    handles = [ handles plot_angle_vs_time(mm, mm_error_log, epoch(k)) ];

    %Plot the angle vs time and the lambda values
    handles = [ handles plot_angle_and_lambda(mm, mm_error_log, epoch(k)) ];

    %To make them all have the same size, ready for import into LaTeX.
    for i=1:length(handles)
        set(handles(i), 'Position', [ 1 1 680 1050 ], 'PaperPositionMode', 'auto');
    end

    %Save pdf-file if a filename prefix is supplied.
    if ~isempty(filename_prefix)
        %Allow for correction of the legends before saving.
        input('Press enter to save the files - i.e. make adjustments to the legends NOW!')

        saveas(handles(1), sprintf('%s_performance_epoch%i.pdf', filename_prefix, epoch(k)));
        saveas(handles(2), sprintf('%s_angle_vs_time_epoch%i.pdf', filename_prefix, epoch(k)));
        saveas(handles(3), sprintf('%s_angle_and_lambda_epoch%i.pdf', filename_prefix, epoch(k)));
        
        %Close the figures
        close(handles);
    end

end