%Computes the feedback error. The error is simply based on the difference
%between the actual trajectory and the desired trajectory, multiplied with
%a constant (the feedback error gain). This allows for the architecture to
%find any inverse model that will solve a given problem. Compared to direct
%learning (where the inputs and outputs are reversed) this is more stable
%and guarantees a solution.
%
%The derivative of x and old_x is not computed. Note that the motor
%commands have to correspond to the dimensions of the state.
%
%ufb = feedback_error(old_x_desired, x, K)
%
%Inputs:
%
%old_x_desired: The x' at the previous timestep.
%
%x: The current state, x.
%
%K: The feedback error gain.
%
%Outputs:
%
%ufb: The feedback error motor command.

function ufb = feedback_error(old_x_desired, x, K)

ufb = ( old_x_desired - x ) .* K;