%Calculates the likelihood based on the difference between predicted/actual
%state (this difference is computed by the calling function), assuming that
%the prediction is contaminated with gaussian noise, with a standard
%deviation sigma.
%
%lh = likelihood(x_x, sigma)
%
%Inputs:
%
%x_x: The difference between the predicted and actual state (computed by
%the caller of the function). 
%
%sigma: The sigma value in the gaussian distribution.
%
%Outputs:
%
%lh: The likelihood that this was a god prediction, assuming that the
%prediction was contaminated with gaussian noise with standard deviation
%sigma.

function lh = likelihood(x_x, sigma)

lh = exp(- (abs(x_x)^2)/(2*sigma^2)) / ( sigma * sqrt(2*pi) );