%Initializes context information in the multiple models, i.e. the
%old_forward and old_desired_state, and also wipes out the memory of the
%networks. Typically called before each training epoch, to avoid memory
%being passed on from the previous epoch.
%
%mm = mm_init_context(mm, init_state)
%
%Inputs:
%
%mm: The multiple model.
%
%init_state: The initial state of the environment. The old_x_desired and
%old_forward variables will be set to this initial state. At time = 0,
%there will be no difference between the current state and the previous
%state, since there was no previous state. 
%
%Outputs:
%
%mm: The multiple model, with wiped memory.

function mm = mm_init_context(mm, init_state)

%Initializing the old_forward and old_x_desired matrices and the context
%unit values (i.e. the hidden node values) of the neural networks in the
%multiple model architecture. This is to ensure that the memory of the
%network is wiped every time it is trained again. 
for i=1:length(mm)
    mm(i).old_forward = init_state;
    mm(i).old_x_desired = init_state;
    mm(i).inverse.context = mm(i).inverse.context .* 0;
    mm(i).forward.context = mm(i).forward.context .* 0;
    mm(i).rp.context = mm(i).rp.context .* 0;
end