function h = plot_angle_and_lambda(mm, mm_error_log, epoch)

%Create the figure.
h = figure('Name', sprintf('Angle vs time, both target and actual trajectory with lambda values, epoch %i', epoch));

%Fetch the error for the given epoch
error_log = mm_error_log(epoch).err;

%Find out how many headers there are.
num_plots = length(mm(1).header);

colors = [ 'b' 'r' 'm' 'c' 'g' 'y' 'k'];

%colors = [ 214/255 228/255 1 ; 1 214/255 214/255 ; 249/255 214/255 1; 167/255 1 232/255; 214/255 1 241/255 ;1 1 214/255; .8 .8 .8 ];

for i=1:num_plots
    %Plot the lambda values as areas with color.
    subplot(num_plots, 1, i)
    hold on;
    for j=1:length(mm)
        area(error_log(j).lambda, 'FaceColor', colors(j));
        alpha(.1);
        module_labels(j) = { sprintf('Module %i', j) };
    end
    
    %Plot the desired state.
    subplot(num_plots, 1, i);
    plot(mm(1).desired_state(i,:), 'b');

    %Plot the actual state achieved by the multiple model.
    subplot(num_plots, 1, i);
    plot(mm_error_log(epoch).actual_state(i,:), 'r');
    hold off;
    xlabel(mm(1).header(i));

    %Concatenate the labels.
    all_labels = [ module_labels {'Target state'} {'Actual state'} ];
    
    %Only put a label on the first plot
    if i == 1
        legend(all_labels);
    end
end