%Plots the angle versus time profile for both the desired state (i.e.
%target) and what was actually performed by the simulator.
%
%h = plot_angle_vs_time(mm, error_log, epoch)
%
%Inputs:
%
%mm: The multiple model structure
%
%error_log: The error log gathered through a simulation run.
%
%epoch: The epoch that is to be plotted.
%
%Outputs:
%
%h: The handle to the figure.

function h = plot_angle_vs_time(mm, error_log, epoch)

%Create the figure.
h = figure('Name', sprintf('Angle vs time, both target and actual trajectory for epoch %i', epoch));

%Find out how many headers there are.
num_plots = length(mm(1).header);

for i=1:num_plots
    %Plot the desired state.
    subplot(num_plots, 1, i);
    plot(mm(1).desired_state(i,:), 'b');
    hold on;
    %Plot the actual state achieved by the multiple model.
    subplot(num_plots, 1, i);
    plot(error_log(epoch).actual_state(i,:), 'r');
    hold off;
    xlabel(mm(1).header(i));
    
    %Only put a label on the first plot
    if i == 1
        legend( {'Target state', 'Actual state'});
    end
end