%Plots the forward error of all the modules, the feedback motor error
%command, the lambda values and all the lambda values superposed. 
%
%h = plot_epoch(error_log, epoch, context)
%
%Inputs: 
%
%error_log: The error log gathered through the simulation run.
%
%epoch: The epoch that is to be plotted.
%
%context: The context sensor input.
%
%Outputs:
%
%h: The handle to the figure.

function h = plot_epoch(total_error_log, epoch, context)

h = figure('Name', [ 'Plot of epoch ' num2str(epoch) ]);

error_log = total_error_log(epoch).err;

total_plot_size = length(error_log)*2 + 2;
plot_counter = 0;

%To colorize each module. Now it will only work with 7 modules. If this is
%to be extended, do a simple [] concatenation. Or extend with random color
%values. 
colors = [ 'b' 'r' 'm' 'c' 'g' 'y' 'k'];

%Plots the forward errors and the corresponding lambda values.
for i=1:length(error_log)
    plot_counter = plot_counter + 1;
    
    subplot(total_plot_size,1,plot_counter);
    plot(error_log(i).forward, colors(i));

    xlabel([ 'Summation of the absolute values of the forward errors, module ' num2str(i) ]);
    
    plot_counter = plot_counter + 1;    
    
    subplot(total_plot_size,1,plot_counter);
    plot(error_log(i).lambda, colors(i));
    
    hold on;
    %Plot the responsibility predictor signals.
    plot(error_log(i).rp, 'g--');
    hold off;
    
    xlabel([ 'Lambda values and responsibility predictor output, module ' num2str(i) ]);
    
    legend({'\lambda', 'rp'});
    

end

%Plots the ratio of the inverse error (ufb) to the actual motor command.
subplot(total_plot_size, 1, total_plot_size-1);
plot(error_log(1).ratio, colors(end));
%The ratio can be 1 at max.
ylim([ 0 1 ]);
xlabel('Ratio of feedback error motor command (ufb)/actual motor command');

%The gray shades.
gray = [ 0.8 0.8 0.8 ];

%Plot the context values.
for i=1:size(context,1)
    subplot(total_plot_size, 1, total_plot_size);
    area(context(i,:), 'FaceColor', gray);
    gray = gray - 0.05;
    hold on;
end


%Plot the lambda values on top of each other.
for i=1:length(error_log)
    subplot(total_plot_size,1,total_plot_size);
    plot(error_log(i).lambda, colors(i));
end
xlabel('All lambda values superposed. Shades of gray indicate context values.');