%Creates a recurrent neural network (i.e. an Elman network) with three
%layers.
%
%R = rnn(rnn_size, learning_rate)
%
%Inputs:
%
%rnn_size: A matrix of the form [input hidden output]that determines the
%size of the recurrent neural network.
%
%learning_rate: The learning rate used to train the network.
%
%Outputs:
%
%R: The recurrent neural network, a structure holding activation layers,
%context information (i.e. memory) and weight matrices. 

function R = rnn(rnn_size, learning_rate)

%Store the size for convenience
R.size = rnn_size;

%Learning rate
R.lr = learning_rate;

%Two matrices with weights
R.w = cell(1,2);

%The activation function for the output layer
%R.output_activation = output_activation;

%rnn_size(1) + rnn_size(2) = the total number of inputs. Since this is a
%reurrent network, the hidden layer (rnn_size(2)) will also be a part of
%the input of the first layer, therefore they are added together.
%
%One extra column is added to hold the bias weights. 
%
%The matrix is of the form: outputs x inputs. This is to facilitate the
%computation of the output nodes at each layer. In this form, it is merely
%to multiply the weight matrix with the horizontal input vector (add an
%extra 1 at the top for bias). This is also what Diego does.
R.w{1} = normrnd(0, 0.2, rnn_size(2), rnn_size(1) + rnn_size(2) + 1);
R.w{2} = normrnd(0, 0.2, rnn_size(3), rnn_size(2) + 1);

%Three activation layers
R.L = cell(1,3);

%Could be zeros, but I'm lazy. 
R.L{1} = [];
R.L{2} = [];
R.L{3} = [];

%The context units. Initially set to zero.
R.context = zeros( rnn_size(2), 1 );