%Activation function for the recurrent neural network.
%
%net = rnn_activate(net, X)
%
%Inputs:
%
%net: The neural network structure, holding the matrices with the neural
%network weights.
%
%X: The input data.
%
%Outputs:
%
%net: The neural network, holding the activation at the input, hidden and
%output level.

function net = rnn_activate(net, X)

%Joining the input data X with the context (i.e. the previous hidden node
%activation).
net.L{1} = [ X; net.context ];

%Calculate hidden layer activation. Adding 1 to the input vector for the
%bias, the last column is now the bias value.
net.L{2} = logsig(net.w{1} * [ net.L{1} ; 1 ]);

%Saving the context information for next activation of the neural network.
%Note: it is not strictly necessary to explicitly save it in another
%variable, I could have used just L{2} earlier. However, it is stored in a
%variable net.context for the sake of readability of the code.
net.context = net.L{2};

%Calculate output layer activation. Adding 1 to the input vector for bias.
%Last column is bias value.
net.L{3} = logsig(net.w{2} * [ net.L{2} ; 1]);