%Separates a string into an array of strings, based on a token delimiter.
%
%function tokens = tokenize(composite_string, delimiter)
%
%Inputs:
%
%composite_string: The string to be tokenized.
%
%delimiter: The delimiter for the tokens. Note that tabs is ASCII 9,
%carriage return is ASCII 13, and space is ASCII 32. So if you want to use
%tabs as the delimiter, write: tokenize(string, 9)
%
%Outputs:
%
%tokens: A cell array holding the strings. Access the ith word by writing
%tokens(i)

function tokens = tokenize(composite_string, delimiter)

remain = composite_string;

tokens = [];

while true
    %Tokenize up to the first occurence of the delimiter.
    [str, remain] = strtok(remain, delimiter);
    if isempty(str),  break;  end
    %Concatenate the string - automatically converts to a cell array since
    %str is in {}.
    tokens = [ tokens {str} ];
end