% Function for testing the performance of a neural network
% 
% function correct = test_ann(net, in, out, criterion)
%
% Inputs:
% net: The network to test
% in: An array of input patterns to use as test instances.
% out: An array of output patterns to use as test instances. in and out
% should be arranged in such as way that in(:,I) is the input pattern for
% out(:,I) for all I.
% criterion: How much the actual output can diverge from the desired output
% while still being counted as a correct classification.
%
% Outputs:
% The number of patterns where all outputs where within the criterion of
% the desired outputs.
function correct = test_ann(net, in, out, criterion)
    correct = 0;
    num_test_patts = size(in,2);
    for j = 1 : num_test_patts        
        tnet = ann_activate(net, in(:,j));
        err = out(:,j) - tnet.L{3};
        if(abs(err)<criterion)
            correct = correct+1;
        end
    end