function [normal_best, pseudo_res] = analyze_cf_results(testname)

    % A helper function for converting the data structure names
    % into names suitable for display in a plot
    function ans = replace_name(inp)
        if strcmp(inp, 'log_8')
            ans = '8 Psuedo patterns';
        elseif strcmp(inp,'log_32')
            ans = '32 Pseudo patterns';
        elseif strcmp(inp,'log_128')
            ans = '128 Pseudo patterns';
        elseif strcmp(inp,'log_500')
            ans = '500 Pseudo patterns';
        else
            ans = inp;
        end
    end

    normal = load(strcat('cf_', testname, '.mat'));
    pseudo = load(strcat('pseudo_', testname, '.mat'));

    hold off;
    pseudo = orderfields(pseudo);
    names = fieldnames(pseudo);
    minlen = size(normal.runs.avg.third.mean, 2);
    halfval = max(normal.runs.avg.first.mean)/2;
    
    normal_best = find(normal.runs.avg.third.mean<halfval, 1, 'first');
    pseudo_res.best = -1;
    
    %Keep an array of names for the plot.
    plotnames = strvcat('Backpropagation', '50% Performance');
    
    %Loop for finding the best pseudo solution and for finding
    for i=1:size(names)
        p = pseudo.(char(names(i)));        
        plotnames = strvcat(plotnames, replace_name(char(names(i))));
        l = size(p,2);
        if l<minlen;
            minlen = l;
        end
        half_this = find(p<halfval, 1, 'first');
        
        %Store the half-point for this pseudo test
        pseudo_res.(char(names(i))) = half_this;
        
        %If the half-point was not found, the best possible performance
        %was achieved, so update that
        if size(half_this,2)==0
            pseudo_res.best = zeros(1,0);
        end
        
        %Otherwise if the half-point is after the current best, update
        %current best as well
        if size(pseudo_res.best,2)~=0
            if half_this>pseudo_res.best
                pseudo_res.best = half_this;
            end
        end
    end

    %Create the line that will show the 50% performance point
    half = zeros(1, minlen);    
    half(:,:) = halfval;

    %Start plotting
    hold on;
    plot(normal.runs.avg.third.mean(1:minlen), 'k');
    plot(half, 'k--');    

    graphtypes = strvcat('-', '--', ':', 'r-', 'r-.', 'r--', 'r:');
    for i=1:size(names)
        p = pseudo.(char(names(i)));
        plot(p(1:minlen), graphtypes(i,:));        
    end
    
    legend(plotnames);
    xlabel('Epochs');
    ylabel('Test patterns correctly classified');
    hold off;
end