% Peform the activation sharpening algorithm on an array of nodes.
% These nodes are assumed to be the output values of the hidden layer in a
% 3-layered neural network.
%
% function hidden_layer = activation_sharpening(hidden_layer, k,
% sharpening_factor)
%
% Inputs:
% net: A network already activated (using ann_activate/rnn_activate)
% k: The number of nodes to increase the output value of. n-k nodes will be
%    reduced
% sharpening_factor: How much to 'sharpen' the outputs. A high factor will
%    lead to greater differences between the hidden layer provided as input
%    and the hidden layer produced as output.
%
% Outputs:
% A network with sharpened nodes.
function net = activation_sharpening(net, k, sharpening_factor)

    % Sharpen a value.
    % Inputs:
    % val: The value to sharpen. This is assumed to be between 0 and 1
    % apply_sharpening: Boolean value determining saying if the value is
    % among the k highest (and should be increased) or among the k lowest
    % and should be lowered
    %
    % Output:
    % ans: The sharpened value
    function ans = sharpen(val, apply_sharpening)
        if apply_sharpening
            ans = val + sharpening_factor*(1-val);
        else
            ans = val - sharpening_factor*val;
        end
    end

    hidden_layer = net.L{2};
    sorted = sort(hidden_layer, 'descend');
    border_val = sorted(k+1);
    sharpen_nodes = hidden_layer>border_val;
    hidden_layer = arrayfun(@sharpen, hidden_layer, sharpen_nodes);
    hidden_errors = net.L{2}-hidden_layer;

    %Updating w1. Adding 1 for the input bias. Backpropagating error from
    %the hidden layer.
    for i=1:length(hidden_errors)
        net.w{1}(i,:) = net.w{1}(i,:) + net.lr .* hidden_errors(i) .* [ net.L{1}' 1 ];
    end
end