% Calculates the average grouped input overlap with each of the different 
% output classes being in a separate subset in each sample.
%
% function avg_gio = average_grouped_input_overlap(input, output)
%
% Inputs:
% input: A matrix containing an input pattern at each row
% output: A matrix containing an output pattern at each row. The output
% must be with 1-of-C encoding where each column is a different class with
% a 1 if the instance is in that class and a 0 otherwise
%
% Output: An average GIO structure containing the mean, max, mean relative
% to max and standard deviation
function avg_gio = average_grouped_input_overlap(input, output)
    classes = size(output,2);
    overlaps = zeros(1, classes);
    max_gios = zeros(1, classes);
    for i = 1:classes
        indexes = output(:,i)==0;
        first_set = submatrix(input, indexes);
        indexes = output(:,i)==1;
        second_set = submatrix(input, indexes);
        overlaps(i) = grouped_input_overlap(first_set, second_set);
        max_gios(i) = max_gio(first_set, second_set);
    end
    avg_gio.mean = mean(overlaps);
    avg_gio.std = std(overlaps);
    avg_gio.theoretical_max = mean(max_gios);
    avg_gio.percent = 100*(avg_gio.mean/avg_gio.theoretical_max);
