% Calculate the average input overlap from a set of data files
%
% function avg_io = input_overlap_averaged(file_prefix, load_fun, num)
%
% Inputs:
% file_prefix: The prefix of the data files. The file names must be
%   <file_prefix><id>.data where id is in the range [1,num]
% load_fun: The dataset loading function to use for loading each data set.
%   This function must accept one parameter (the file name) and return two
%   values: The input and output data as matrixes with one instance per
%   row. 
% num: The number of data files to use for the calculation
%
% Output: A data structure containing the mean, standard, theoretical
% maximum, and percentage of theoretical maximum of the calculated input
% overlaps 
function avg_io = input_overlap_averaged(file_prefix, load_fun, num)
    ios = zeros(1, num);
    max_ios = zeros(1, num);
    nominal_ios = zeros(1,num);
    for i = 1:num
        [input, output] = load_fun(strcat(file_prefix, int2str(i), ... 
            '.data'));
        ios(i) = input_overlap(input);
        max_ios(i) = max_io(input);
        nominal_ios(i) = ios(i)/max_ios(i);
        %Calculate average grouped input overlap for each
        for j=1:size(output,2)
            
    end
    avg_io.mean = mean(ios);
    avg_io.std = std(ios);
    avg_io.theoretical_max = mean(max_ios);
    avg_io.percent = 100*(avg_io.mean/avg_io.theoretical_max);
end
