% Calculate the average input overlap from a set of data files
%
% function avg_io = input_overlap_averaged(file_prefix, load_fun, num)
%
% Inputs:
% file_prefix: The prefix of the data files. The file names must be
%   <file_prefix><id>.data where id is in the range [1,num]
% load_fun: The dataset loading function to use for loading each data set.
%   This function must accept one parameter (the file name) and return two
%   values: The input and output data as matrixes with one instance per
%   row. 
% num: The number of data files to use for the calculation
%
% Output: A data structure containing the mean, standard, theoretical
% maximum, and percentage of theoretical maximum of the calculated input
% overlaps 
function avg_gio = grouped_input_overlap_averaged(file_prefix, load_fun, ...
    num)
    gios = zeros(1, num);
    max_gios = zeros(1, num);
    nominal_gios = zeros(1,num);
    for i = 1:num
        [input, output] = load_fun(strcat(file_prefix, int2str(i), ... 
            '.data'));

        %Select a random class for second set
        second_class = floor(rand*size(output,2))+1; 
        
        %Create First and Second set
        indexes = output(:,second_class)==0;
        first_set = submatrix(input, indexes);
        indexes = output(:,second_class)==1;
        second_set = submatrix(input, indexes);

        %Calculate overlap and max
        gios(i) = grouped_input_overlap(first_set, second_set);        
        max_gios(i) = max_gio(first_set, second_set);
        nominal_gios(i) = gios(i)/max_gios(i);
    end
    avg_gio.mean = mean(gios);
    avg_gio.std = std(gios);
    avg_gio.theoretical_max = mean(max_gios);
    avg_gio.percent = 100*(avg_gio.mean/avg_gio.theoretical_max);
