% Run an experiment a given number of times.
%
% function runs = run_averaged_experiment(file, one_file, experiment, ...
%    numruns)
% Inputs:
% file - The string prefixing all data sets in the test run if different
%   datasets are used or the filename to use for all tests if one dataset
%   is used.
% one_file - If 1, then all runs will be conducted using data in dataset
%   with filename <file>. Otherwise run I will be run with data from file
%   <file><I>.data
% experiment - The function to be used to run the experiment. This should
%   return three values: The first training with initial data, the result
%   of training it with a second set of data, and the result of testing the
%   first data during the secondary training
% numruns - The number of times to run the experiment
%
% Outputs:
% The data structure containing all the runs
function runs = run_averaged_experiment(file, one_file, experiment, ...
    numruns)
    runs.data = [];
    s1 = [];
    s2 = [];
    s3 = [];
    for i=1:numruns
        disp(sprintf('Starting run %d', i))
        if one_file==1
            fname = file;
        else            
            fname = strcat(file, int2str(i), '.data');
        end
        [first, second, third] = experiment(fname);
        run.first = first;
        run.second = second;
        run.third = third;
        s1 = [s1; first.testlog];
        s2 = [s2; second.testlog];
        s3 = [s3; third.testlog];        
        runs.data = [runs.data run];
    end
    runs.avg.first.mean = mean(s1);
    runs.avg.first.stddev = std(s1);
    runs.avg.second.mean = mean(s2);    
    runs.avg.second.stddev = std(s2);
    runs.avg.third.mean = mean(s3);
    runs.avg.third.stddev = std(s3);